{% extends "base.html" %}

{% block title %}{{ product.name }} - Wilco Shop | Starlette{% endblock %}

{% block content %}
<a href="/" class="back-link">&larr; Back to Products</a>
{{ widget }}
{% endblock %}
