<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Wilco Shop | WSGI{% endblock %}</title>
    <link rel="stylesheet" href="/static/theme.css">
    {% block extra_head %}{% endblock %}
</head>
<body>
    <header>
        <h1>
            <span class="logo"></span>
            <a href="/">Wilco Shop | WSGI</a>
        </h1>
    </header>

    <main>
        {% block content %}{% endblock %}
    </main>

    <footer>
        <p>Minimal WSGI Example - wilco Component Framework</p>
    </footer>

    <!-- wilco component loader -->
    <script src="/wilco-static/wilco/loader.js"{% if wilco_manifest_url %} data-wilco-manifest="{{ wilco_manifest_url }}"{% endif %} defer></script>
    {% block extra_scripts %}{% endblock %}
</body>
</html>
