{% extends "base.html" %}

{% block title %}Not Found - Wilco Shop | Starlette{% endblock %}

{% block content %}
<div style="text-align: center; padding: 4rem 2rem;">
    <h2>404 - Not Found</h2>
    <p style="color: #666; margin: 1rem 0;">{{ message }}</p>
    <a href="/" style="color: #8e44ad;">Back to Products</a>
</div>
{% endblock %}
