{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Wilco Shop | Django Unfold{% endblock %}</title>
    <link rel="apple-touch-icon" sizes="180x180" href="{% static 'apple-touch-icon.png' %}">
    <link rel="icon" type="image/png" sizes="32x32" href="{% static 'favicon-32x32.png' %}">
    <link rel="icon" type="image/png" sizes="16x16" href="{% static 'favicon-16x16.png' %}">
    <link rel="manifest" href="{% static 'site.webmanifest' %}">
    <link rel="stylesheet" href="{% static 'theme.css' %}">
</head>
<body>
    <header>
        <h1>
            <span class="logo"></span>
            <a href="{% url 'store:product_list' %}">Wilco Shop | Django Unfold</a>
        </h1>
        <nav><a href="{% url 'admin:index' %}">Admin</a></nav>
    </header>
    <main>
        {% block content %}{% endblock %}
    </main>
</body>
</html>
