{% extends "base.html" %}

{% block title %}Not Found - Wilco Shop | Flask{% endblock %}

{% block content %}
<div style="text-align: center; padding: 4rem 2rem;">
    <h1 style="font-size: 4rem; color: #ccc;">404</h1>
    <p style="font-size: 1.2rem; color: #666; margin-top: 1rem;">{{ message }}</p>
    <a href="/" style="display: inline-block; margin-top: 2rem; color: #2c3e50;">
        &larr; Back to Home
    </a>
</div>
{% endblock %}
