{% extends "base.html" %}

{% block title %}Page Not Found{% endblock %}

{% block content %}
<div class="error-page">
    <h2>404</h2>
    <p>The page you're looking for doesn't exist.</p>
    <p><a href="/" class="back-link">Return to homepage</a></p>
</div>
{% endblock %}
