{% extends "base.html" %}

{% block title %}{{ product.name }} - Wilco Shop | Django{% endblock %}

{% block content %}
<a href="{% url 'store:product_list' %}" class="back-link">&larr; Back to Products</a>

{{ widget }}
{% endblock %}
