<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Wilco Shop | Flask{% endblock %}</title>
    <link rel="apple-touch-icon" sizes="180x180" href="/static/apple-touch-icon.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/static/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/static/favicon-16x16.png">
    <link rel="stylesheet" href="/static/theme.css">
</head>
<body>
    <header>
        <h1>
            <span class="logo"></span>
            <a href="/">Wilco Shop | Flask</a>
        </h1>
        <nav><a href="/admin/">Admin</a></nav>
    </header>
    <main>
        {% block content %}{% endblock %}
    </main>
    <script src="/wilco-static/wilco/loader.js"{% if wilco_manifest_url %} data-wilco-manifest="{{ wilco_manifest_url }}"{% endif %} defer></script>
</body>
</html>
